==> openshift-serverless-logic-1.28.0-src.zip: openshift-serverless-logic-1.28.0.GA-src/org.kie.kogito-kogito-apps-1.35.0.Final/ui-packages/packages/workflow-form/src/embedded/EmbeddedWorkflowForm.tsx <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useCallback, useMemo } from 'react';
import { EnvelopeServer } from '@kogito-tooling/envelope-bus/dist/channel';
import { EmbeddedEnvelopeFactory } from '@kogito-tooling/envelope/dist/embedded';
import {
  WorkflowDefinition,
  WorkflowFormApi,
  WorkflowFormChannelApi,
  WorkflowFormDriver,
  WorkflowFormEnvelopeApi
} from '../api';
import { EmbeddedWorkflowFormChannelApiImpl } from './EmbeddedWorkflowFormChannelApiImpl';
import { init } from '../envelope';
import { ContainerType } from '@kogito-tooling/envelope/dist/api';

export interface EmbeddedWorkflowFormProps {
  targetOrigin: string;
  driver: WorkflowFormDriver;
  workflowDefinition: WorkflowDefinition;
}

export const EmbeddedWorkflowForm = React.forwardRef<
  WorkflowFormApi,
  EmbeddedWorkflowFormProps
>((props, forwardedRef) => {
  const pollInit = useCallback(
    (
      envelopeServer: EnvelopeServer<
        WorkflowFormChannelApi,
        WorkflowFormEnvelopeApi
      >,
      container: () => HTMLDivElement
    ) => {
      init({
        config: {
          containerType: ContainerType.DIV,
          envelopeId: envelopeServer.id
        },
        container: container(),
        bus: {
          postMessage(message, targetOrigin, transfer) {
            window.postMessage(message, '*', transfer);
          }
        }
      });
      return envelopeServer.envelopeApi.requests.workflowForm__init(
        {
          origin: envelopeServer.origin,
          envelopeServerId: envelopeServer.id
        },
        { ...props.workflowDefinition }
      );
    },
    []
  );

  const refDelegate = useCallback(
    (
      envelopeServer: EnvelopeServer<
        WorkflowFormChannelApi,
        WorkflowFormEnvelopeApi
      >
    ): WorkflowFormApi => ({}),
    []
  );

  const EmbeddedEnvelope = useMemo(() => {
    return EmbeddedEnvelopeFactory({
      api: new EmbeddedWorkflowFormChannelApiImpl(props.driver),
      origin: props.targetOrigin,
      refDelegate,
      pollInit,
      config: { containerType: ContainerType.DIV }
    });
  }, []);

  return <EmbeddedEnvelope ref={forwardedRef} />;
});

==> openshift-serverless-logic-1.30.0-src.zip: openshift-serverless-logic-1.30.0.GA-src/org.kie.kogito-kogito-apps-1.40.0.Final/ui-packages/packages/workflow-form/src/embedded/EmbeddedWorkflowForm.tsx <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useCallback, useMemo } from 'react';
import { EnvelopeServer } from '@kogito-tooling/envelope-bus/dist/channel';
import { EmbeddedEnvelopeFactory } from '@kogito-tooling/envelope/dist/embedded';
import {
  WorkflowDefinition,
  WorkflowFormApi,
  WorkflowFormChannelApi,
  WorkflowFormDriver,
  WorkflowFormEnvelopeApi
} from '../api';
import { EmbeddedWorkflowFormChannelApiImpl } from './EmbeddedWorkflowFormChannelApiImpl';
import { init } from '../envelope';
import { ContainerType } from '@kogito-tooling/envelope/dist/api';

export interface EmbeddedWorkflowFormProps {
  targetOrigin: string;
  driver: WorkflowFormDriver;
  workflowDefinition: WorkflowDefinition;
}

export const EmbeddedWorkflowForm = React.forwardRef<
  WorkflowFormApi,
  EmbeddedWorkflowFormProps
>((props, forwardedRef) => {
  const pollInit = useCallback(
    (
      envelopeServer: EnvelopeServer<
        WorkflowFormChannelApi,
        WorkflowFormEnvelopeApi
      >,
      container: () => HTMLDivElement
    ) => {
      init({
        config: {
          containerType: ContainerType.DIV,
          envelopeId: envelopeServer.id
        },
        container: container(),
        bus: {
          postMessage(message, targetOrigin, transfer) {
            window.postMessage(message, targetOrigin, transfer);
          }
        }
      });
      return envelopeServer.envelopeApi.requests.workflowForm__init(
        {
          origin: envelopeServer.origin,
          envelopeServerId: envelopeServer.id
        },
        { ...props.workflowDefinition }
      );
    },
    []
  );

  const refDelegate = useCallback(
    (
      envelopeServer: EnvelopeServer<
        WorkflowFormChannelApi,
        WorkflowFormEnvelopeApi
      >
    ): WorkflowFormApi => ({}),
    []
  );

  const EmbeddedEnvelope = useMemo(() => {
    return EmbeddedEnvelopeFactory({
      api: new EmbeddedWorkflowFormChannelApiImpl(props.driver),
      origin: props.targetOrigin,
      refDelegate,
      pollInit,
      config: { containerType: ContainerType.DIV }
    });
  }, []);

  return <EmbeddedEnvelope ref={forwardedRef} />;
});
